@@ -1,18 +1,18 @@
-'''
+"""
 .. include:: ../.GUIDE.md
    :start-line: 4
-'''
+"""
 
 from .fixation import FixationSequence
-from .image import Image, Figure
 from .text import TextBlock
 from . import analysis
 from . import io
 from . import tools
+from . import vis
 
-del fixation, image, text
+del fixation, text
 
 try:
-	from ._version import __version__
+    from ._version import __version__
 except ImportError:
-	__version__ = '???'
+    __version__ = "???"
